#!/usr/bin/env python
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='authsrv',
    version='0.0.2',
    description='wrapper for authsrv utilities',
    license='MIT',
    packages=setuptools.find_packages(),
    author='Nathan Neulinger',
    author_email='nneul@neulinger.org',
    keywords=['authsrv'],
    url='https://github.com/unixtools/authsrv-python',
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python",
        "Topic :: Internet",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ]
)



'''
Wrapper around authsrv utilities from https://github.com/unixtools/authsrv
'''

# AuthSrv_Fetch
# AuthSrv_FetchRaw
# AuthSrv_SetPathPrefix

import subprocess
import getpass

__author__ = 'nneul'


def fetch(owner: str = None, user='', instance=''):
    '''Retrieve a stash from authsrv'''

    if owner is None:
        owner = getpass.getuser()

    password = subprocess.check_output(["authsrv-decrypt", owner, user, instance])
    password = password.decode('utf-8')
    password = password.rstrip('\n\r')

    return password
